@@ -104,9 +104,9 @@ class TileSet(object):
 
         for i in diagram.sequence:
             if i % 2:
-                player = diagram.first
+                player = diagram.first_player
             else:
-                player = diagram.second
+                player = diagram.second_player
             x, y = diagram.sequence[i]
             box = (x*self.tile_size[0], y*self.tile_size[1],
                    (x+1)*self.tile_size[0], (y+1)*self.tile_size[1])
@@ -202,23 +202,24 @@ class GoDiagram(object):
             initial_black=parser.initial_black,
             initial_white=parser.initial_white,
             sequence=parser.sequence_moves,
-	    annotated_moves=parser.annotated_moves
+	    annotated_moves=parser.annotated_moves,
+	    first_player=parser.first_player,
         )
 
-    def __init__(self, board=Board(), initial_black=None, initial_white=None, sequence=None, annotated_moves=None, first='black'):
+    def __init__(self, board=Board(), initial_black=None, initial_white=None, sequence=None, annotated_moves=None, first_player='black'):
         self.board = board
         self.initial_black = initial_black or set()
         self.initial_white = initial_white or set()
         self.sequence = sequence or {}
         self.annotated_moves = annotated_moves or {}
-        self.first = first
-        if self.first == 'black':
-            self.second = 'white'
-        elif self.first == 'white':
-            self.second = 'black'
+        self.first_player = first_player
+        if self.first_player == 'black':
+            self.second_player = 'white'
+        elif self.first_player == 'white':
+            self.second_player = 'black'
         else:
-            self.first = 'black'
-            self.second = 'white'
+            self.first_player = 'black'
+            self.second_player = 'white'
         self.tiles = TileSet('tiny')
 
     def render(self):
