@@ -3,8 +3,9 @@ class MalformedGoDiagram(ValueError):
     pass
 
 class GoDiagramParser(object):
+    line_prefix = '$$'
+
     def __init__(self):
-        self.line_prefix = ''
         self.top_edge = False
         self.left_edge = False
         self.right_edge = False
@@ -15,42 +16,57 @@ class GoDiagramParser(object):
         self.initial_white = set()
         self.sequence_moves = {}
         self.annotated_moves = {}
-        self.board_parsed = False
+        self.first_player = None
+        self._state = 'header'
 
     def board_size(self):
         return self.board_width, self.board_height
 
     def parse(self, board):
-        board = iter(board)
-        self.parse_header(board.next())
-        for line in board:
-            if not self.board_parsed:
+	for line in board:
+            if self._state == 'header':
+                self.parse_header(line)
+            if self._state == 'board':
                 self.parse_board(line)
-            else: 
+            if self._state == 'footer':
                 self.parse_footer(line)
 
     def parse_header(self, line):
+        header_line = False
         line = line.strip()
-        if line.startswith('$$'):
-            self.line_prefix = '$$'
+        if line.startswith(self.line_prefix + 'W'):
+            header_line = True
+            self.first_player = 'white'
+            prefix = self.line_prefix + 'W'
+        elif line.startswith(self.line_prefix + 'B'):
+            header_line = True
+            self.first_player = 'black'
+            prefix = self.line_prefix + 'B'
+        elif line.startswith(self.line_prefix):
+            prefix = self.line_prefix
+        else:
+            raise MalformedGoDiagram("All lines must start with $$")
+
         if '---' in line:
-            line = line[len(self.line_prefix):]
+            header_line = True
+            line = line[len(prefix):]
             line = line.strip()
             # top border:
             if any(c != '-' for c in line):
                 raise MalformedGoDiagram('Top edge must consist of only "-" characters')
             self.top_edge=True
-        else:
+        if not header_line:
+            self._state = 'board'
             self.parse_board(line)
                 
     def parse_board(self, line):
         line = line.strip()
         if not line.startswith(self.line_prefix):
-            raise MalformedGoDiagram("All lines must start with $$ if any lines start with $$")
+            raise MalformedGoDiagram("All lines must start with $$")
         line = line[len(self.line_prefix):]
         line = line.strip()
         if '---' in line:
-            self.board_parsed = True
+            self._state == 'footer'
             self.parse_footer(line)
         else:
             self.board_height += 1
@@ -64,7 +80,7 @@ class GoDiagramParser(object):
             if not self.board_width:
                 self.board_width = len(points)
             elif self.board_width != len(points):
-                raise MalformedGoDiagram("All lines must be the same length")
+                raise MalformedGoDiagram("All lines must have the same number of points")
             for i, point in enumerate(points):
                 coord = (i, self.board_height - 1)
                 if point == 'X':
@@ -85,7 +101,7 @@ class GoDiagramParser(object):
         if '---' in line:
             self.bottom_edge = True
             if any(c != '-' for c in line):
-                raise MalformedGoDiagram('Top edge must consist of only "-" characters')
+                raise MalformedGoDiagram('Bottom edge must consist of only "-" characters')
         else:
             #Not handling other footer information yet.
             pass
