@@ -20,6 +20,7 @@ class GoDiagramDirective(ImageDirective):
     Looks like:
   
     ..go:: filename.png
+
         $$ -----------
         $$ | . . . . .
         $$ | . . O . .
@@ -43,7 +44,7 @@ class GoDiagramDirective(ImageDirective):
         self.assert_has_content()
         node = godiagram_node()
         node['content'] = self.content
-        node['alt'] = self.options['alt']
+        node['alt'] = self.options.get('alt', '')
         if self.arguments:
             node['filename'] = self.arguments[0] 
         else:
